==> data_pipelines_elasticsearch-1.0.0.tar.gz: data_pipelines_elasticsearch/tests/src/Kernel/ElasticsearchDestinationDatasetTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines_elasticsearch\Kernel;

use Drupal\data_pipelines\DatasetPipelinePluginManager;
use Drupal\data_pipelines\Destination\ProcessingOperationEnum;
use Drupal\data_pipelines\Form\DatasetBatchContext;
use Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination;
use Drupal\Tests\data_pipelines\Kernel\DatasetKernelTestBase;
use Drupal\Tests\data_pipelines\Traits\DatasetTestProcessingTrait;
use Drupal\Tests\data_pipelines_elasticsearch\Traits\ElasticsearchTestDestinationTrait;
use Elasticsearch\Client;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;
use Psr\Log\NullLogger;

/**
 * Defines a class for testing elastic indexer.
 *
 * @group data_pipelines
 */
class ElasticsearchDestinationDatasetTest extends DatasetKernelTestBase {

  use ProphecyTrait;
  use ElasticsearchTestDestinationTrait;
  use DatasetTestProcessingTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'data_pipelines_elasticsearch',
    'data_pipelines_elasticsearch_test',
  ];

  /**
   * Tests elasticsearch destinations.
   */
  public function testElasticsearchDestination() {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);
    $this->assertCount(1, $dataset->getDestinations());
  }

  /**
   * Tests multiple destinations.
   */
  public function testMultipleDestinations() {
    $destinations[] = $this->createTestMemoryDestination();
    $destinations[] = $this->createTestFileDestination();
    $destinations[] = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset(['destinations' => $destinations]);
    $this->assertCount(3, $dataset->getDestinations());
  }

  /**
   * Tests elasticsearch destination settings.
   */
  public function testElasticsearchDestinationSettings() {
    $this->initializeElasticClient();

    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);

    $queue_id = $dataset->getProcessingQueueId();
    /** @var \Drupal\Core\Queue\QueueWorkerInterface $queue_worker */
    $process_queue = \Drupal::queue($queue_id);
    $dataset->queueProcessing($process_queue, new DatasetBatchContext($dataset->getBatchSize()));
    $this->processQueueWithWait($queue_id, $destination->id(), [
      ProcessingOperationEnum::Begin,
      ProcessingOperationEnum::ProcessChunk,
      ProcessingOperationEnum::End,
    ]);

    $index = self::INDEX_PREFIX . $dataset->getMachineName();
    $response = $this->client->indices()->getMapping([
      'index' => $index,
    ]);
    $this->assertFalse($response[$index]['mappings']['properties']['firstname']['index'], 'Firstname field marked as not indexed');

    $response = $this->client->indices()->analyze([
      'index' => $index,
      'body' => [
        'analyzer' => 'test_analyzer',
        'text' => '<h1>Dr ABC</h1>',
      ],
    ]);
    $this->assertEquals("\nDr ABC\n", $response['tokens'][0]['token'], 'HTML removed from tokens');
  }

  /**
   * Tests elasticsearch data pipeline plugin.
   */
  public function testElasticsearchDataPipeline() {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);

    $indices = $this->prophesizeIndices(FALSE);
    $params = [
      'index' => self::INDEX_PREFIX . $dataset->getMachineName(),
      'body' => [
        'settings' => [
          'number_of_shards' => ElasticSearchDestination::INDEX_SHARDS,
          'number_of_replicas' => ElasticSearchDestination::INDEX_REPLICAS,
          'codec' => ElasticSearchDestination::INDEX_CODEC,
          'analysis' => [
            'analyzer' => [
              'test_analyzer' => [
                'tokenizer' => 'keyword',
                'char_filter' => [
                  'html_strip',
                ],
              ],
            ],
          ],
        ],
        'mappings' => [
          'properties' => [
            'firstname' => [
              'type' => 'text',
              'index' => FALSE,
            ],
          ],
        ],
      ],
    ];
    $indices->create($params)->shouldBeCalled();
    $client = $this->prophesize(Client::class);
    $client->indices()->willReturn($indices->reveal());

    $client->bulk(Argument::any())->willReturn([]);

    $pipeline_manager = $this->prophesize(DatasetPipelinePluginManager::class);
    $pipeline_manager->hasDefinition(Argument::exact('elasticsearch_test_pipeline_1'))->willReturn(TRUE);

    $indexer = $this->mockIndexer($pipeline_manager->reveal(), new NullLogger(), $client->reveal());
    $this->assertTrue($indexer->beginProcessing($dataset));
    $this->assertTrue($indexer->processChunk($dataset, iterator_to_array($dataset->getDataIterator())));
  }

  /**
   * Tests cleanup processing.
   */
  public function testCleanup(): void {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);
    $indices = $this->prophesizeIndices(TRUE);
    $client = $this->prophesize(Client::class);
    $client->indices()->willReturn($indices->reveal());

    $client->bulk([
      'body' => [
        [
          'delete' => [
            '_index' => self::INDEX_PREFIX . $dataset->getMachineName(),
            '_id' => $dataset->getMachineName() . ':' . 1,
          ],
        ],
        [
          'delete' => [
            '_index' => self::INDEX_PREFIX . $dataset->getMachineName(),
            '_id' => $dataset->getMachineName() . ':' . 2,
          ],
        ],
      ],
    ])->willReturn([]);

    $pipeline_manager = $this->prophesize(DatasetPipelinePluginManager::class);
    $indexer = $this->mockIndexer($pipeline_manager->reveal(), new NullLogger(), $client->reveal());
    $this->assertTrue($indexer->processCleanup($dataset, [1, 2]));
  }

}

==> data_pipelines_elasticsearch-2.0.0.tar.gz: data_pipelines_elasticsearch/tests/src/Kernel/ElasticsearchDestinationDatasetTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\data_pipelines_elasticsearch\Kernel;

use Drupal\data_pipelines\Destination\ProcessingOperationEnum;
use Drupal\data_pipelines\Form\DatasetBatchContext;
use Drupal\Tests\data_pipelines\Kernel\DatasetKernelTestBase;
use Drupal\Tests\data_pipelines\Traits\DatasetTestProcessingTrait;
use Drupal\Tests\data_pipelines_elasticsearch\Traits\ElasticsearchTestDestinationTrait;
use Drupal\data_pipelines\DatasetPipelinePluginManager;
use Drupal\data_pipelines_elasticsearch\Plugin\DatasetDestination\ElasticSearchDestination;
use Elastic\Elasticsearch\Client;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;
use Psr\Log\NullLogger;

/**
 * Defines a class for testing elastic indexer.
 *
 * @group data_pipelines
 */
class ElasticsearchDestinationDatasetTest extends DatasetKernelTestBase {

  use ProphecyTrait;
  use ElasticsearchTestDestinationTrait;
  use DatasetTestProcessingTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'data_pipelines_elasticsearch',
    'data_pipelines_elasticsearch_test',
  ];

  /**
   * Tests elasticsearch destinations.
   */
  public function testElasticsearchDestination() {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);
    $this->assertCount(1, $dataset->getDestinations());
  }

  /**
   * Tests multiple destinations.
   */
  public function testMultipleDestinations() {
    $destinations[] = $this->createTestMemoryDestination();
    $destinations[] = $this->createTestFileDestination();
    $destinations[] = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset(['destinations' => $destinations]);
    $this->assertCount(3, $dataset->getDestinations());
  }

  /**
   * Tests elasticsearch destination settings.
   */
  public function testElasticsearchDestinationSettings() {
    $this->initializeElasticClient();

    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);

    $queue_id = $dataset->getProcessingQueueId();
    /** @var \Drupal\Core\Queue\QueueWorkerInterface $queue_worker */
    $process_queue = \Drupal::queue($queue_id);
    $dataset->queueProcessing($process_queue, new DatasetBatchContext($dataset->getBatchSize()));
    $this->processQueueWithWait($queue_id, $destination->id(), [
      ProcessingOperationEnum::Begin,
      ProcessingOperationEnum::ProcessChunk,
      ProcessingOperationEnum::End,
    ]);

    $index = self::INDEX_PREFIX . $dataset->getMachineName();
    $response = $this->client->indices()->getMapping([
      'index' => $index,
    ])->asArray();
    $this->assertFalse($response[$index]['mappings']['properties']['firstname']['index'], 'Firstname field marked as not indexed');

    $response = $this->client->indices()->analyze([
      'index' => $index,
      'body' => [
        'analyzer' => 'test_analyzer',
        'text' => '<h1>Dr ABC</h1>',
      ],
    ])->asArray();
    $this->assertEquals("\nDr ABC\n", $response['tokens'][0]['token'], 'HTML removed from tokens');
  }

  /**
   * Tests elasticsearch data pipeline plugin.
   */
  public function testElasticsearchDataPipeline() {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);

    $indices = $this->prophesizeIndices(FALSE);
    $params = [
      'index' => self::INDEX_PREFIX . $dataset->getMachineName(),
      'body' => [
        'settings' => [
          'number_of_shards' => ElasticSearchDestination::INDEX_SHARDS,
          'number_of_replicas' => ElasticSearchDestination::INDEX_REPLICAS,
          'codec' => ElasticSearchDestination::INDEX_CODEC,
          'analysis' => [
            'analyzer' => [
              'test_analyzer' => [
                'tokenizer' => 'keyword',
                'char_filter' => [
                  'html_strip',
                ],
              ],
            ],
          ],
        ],
        'mappings' => [
          'properties' => [
            'firstname' => [
              'type' => 'text',
              'index' => FALSE,
            ],
          ],
        ],
      ],
    ];
    $indices->create($params)->shouldBeCalled();
    $client = $this->prophesize(Client::class);
    $client->indices()->willReturn($indices->reveal());

    $client->bulk(Argument::any())->willReturn([]);

    $pipeline_manager = $this->prophesize(DatasetPipelinePluginManager::class);
    $pipeline_manager->hasDefinition(Argument::exact('elasticsearch_test_pipeline_1'))->willReturn(TRUE);

    $indexer = $this->mockIndexer($pipeline_manager->reveal(), new NullLogger(), $client->reveal());
    $this->assertTrue($indexer->beginProcessing($dataset));
    $this->assertTrue($indexer->processChunk($dataset, iterator_to_array($dataset->getDataIterator())));
  }

  /**
   * Tests cleanup processing.
   */
  public function testCleanup(): void {
    $destination = $this->createElasticsearchDestination();
    $dataset = $this->createTestDataset([
      'destinations' => $destination,
      'pipeline' => 'elasticsearch_test_pipeline_1',
    ]);
    $indices = $this->prophesizeIndices(TRUE);
    $client = $this->prophesize(Client::class);
    $client->indices()->willReturn($indices->reveal());

    $client->bulk([
      'body' => [
        [
          'delete' => [
            '_index' => self::INDEX_PREFIX . $dataset->getMachineName(),
            '_id' => $dataset->getMachineName() . ':' . 1,
          ],
        ],
        [
          'delete' => [
            '_index' => self::INDEX_PREFIX . $dataset->getMachineName(),
            '_id' => $dataset->getMachineName() . ':' . 2,
          ],
        ],
      ],
    ])->willReturn([]);

    $pipeline_manager = $this->prophesize(DatasetPipelinePluginManager::class);
    $indexer = $this->mockIndexer($pipeline_manager->reveal(), new NullLogger(), $client->reveal());
    $this->assertTrue($indexer->processCleanup($dataset, [1, 2]));
  }

}
